//-----------------------------------------------------------------------
// <copyright file="Host.cs" company="BME MIT">
//     Released under The Code Project Open License (CPOL) 1.02
//     Based on work of Stephan Meyn and smallguy78
//     Modified by Daniel Darvas, BME MIT
// </copyright>
//-----------------------------------------------------------------------
using System;
using System.Configuration;
using System.Threading;
using System.Xml;

namespace RssAggregator
{
    /// <summary>
    /// This is the host that will run the aggregator
    /// </summary>
    public class Host
    {
        /// <summary>
        /// The main entry point for the application.
        /// </summary>
        /// <param name="args">Command line arguments. Not used.</param>
        [STAThread]
        public static void Main(string[] args)
        {
            Aggregator agg = new Aggregator();
            LoadConfiguration(agg);
            Thread aggThread = new Thread(new ThreadStart(agg.Run));
            aggThread.IsBackground = true; // thread dies when this routine ends
            aggThread.Start();
            while (!agg.ServerRunning)
            {
                Thread.Sleep(100);
            }

            Console.WriteLine("Aggregator started and listening on port {0}. Hit RETURN to terminate.", agg.Port);
            Console.ReadLine();
            Console.WriteLine("Aggregator stopped.");
        }

        /// <summary>
        /// Loads the configuration for the given aggregator server from app.config.
        /// </summary>
        /// <param name="agg">The aggregator server to configure.</param>
        private static void LoadConfiguration(Aggregator agg)
        {
            int ms;
            if (int.TryParse(ConfigurationManager.AppSettings["milliSecondToSleep"], out ms))
            {
                agg.MilliSecondsToSleep = ms;
            }

            string feedPath = ConfigurationManager.AppSettings["feeds"];
            XmlDocument xmlDoc = new XmlDocument();

            try
            {
                xmlDoc.Load(feedPath);
                XmlNode rssFeedsNode = null;

                // Loop child nodes till we find the rssFeed 
                for (int i = 0; i < xmlDoc.ChildNodes.Count; i++)
                {
                    if (xmlDoc.ChildNodes[i].Name.ToUpper() == "RSSFEEDS")
                    {
                        rssFeedsNode = xmlDoc.ChildNodes[i];
                        break;
                    }
                }

                // parse all feeds
                for (int idxFeed = 0; idxFeed < rssFeedsNode.ChildNodes.Count; idxFeed++)
                {
                    if (rssFeedsNode.ChildNodes[idxFeed].Name.ToUpper() == "RSS")
                    {
                        agg.AddRssUrl(rssFeedsNode.ChildNodes[idxFeed].InnerText);
                    }
                }
            }
            catch (XmlException err)
            {
                Console.WriteLine(
                    "Error in configuration file {0}.\r\n Error: {1}",
                    feedPath, 
                    err.Message);
            }
        }
    }
}
