//-----------------------------------------------------------------------
// <copyright file="RssFeedStore.cs" company="BME MIT">
//     Released under The Code Project Open License (CPOL) 1.02
//     Based on work of Stephan Meyn and smallguy78
//     Modified by Daniel Darvas, BME MIT
// </copyright>
//-----------------------------------------------------------------------

using System.Collections.Generic;
using RSSLibrary;

namespace RssAggregator
{
    /// <summary>
    /// RssFeedStore
    /// Version: 0.1   draft
    /// Copyright 2004 (c) Stephan Meyn
    /// Role: a store for RSS Feeds
    /// Responsibilities:
    /// <list type="bullet">
    /// <item>knows individual RSS Feeds</item>
    /// <item>knows status of feeds</item>
    /// </list>
    /// </summary>
    public class RssFeedStore
    {
        #region private fields
        /// <summary>
        /// The RssFeed items are contained here by name
        /// </summary>
        private Dictionary<string, RssFeed> feeds = new Dictionary<string, RssFeed>();
        #endregion

        #region public properties
        /// <summary>
        /// Gets the collection of the feed URLs.
        /// </summary>
        public ICollection<string> Urls
        {
            get
            {
                return this.feeds.Keys;
            }
        }

        /// <summary>
        /// Gets the RssFeed object of the given feed.
        /// </summary>
        /// <param name="url">The URL of the feed.</param>
        /// <returns>The RssFeed object for the given URL.</returns>
        public RssFeed this[string url]
        {
            get
            {
                return this.feeds[url];
            }

            set
            {
                this.feeds[url] = value;
            }
        }

        #endregion

        #region public methods
        /// <summary>
        /// Add a feed URL.
        /// </summary>
        /// <param name="url">URL of the feed.</param>
        public void AddFeed(string url)
        {
            if (!this.feeds.ContainsKey(url))
            {
                this.feeds.Add(url, null);
            }
        }

        /// <summary>
        /// Remove a feed URL and the most recent feed
        /// </summary>
        /// <param name="url">URL of the feed.</param>
        public void RemoveFeed(string url)
        {
            if (this.feeds.ContainsKey(url))
            {
                this.feeds.Remove(url);
            }
        }
        #endregion
    }
}
