﻿//-----------------------------------------------------------------------
// <copyright file="TinyServerException.cs" company="BME MIT">
//     Released under The Code Project Open License (CPOL) 1.02
//     Based on work of Stephan Meyn and smallguy78
//     Modified by Daniel Darvas, BME MIT
// </copyright>
//-----------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.Text;

namespace TinyServerLib
{
    /// <summary>
    /// Exceptions the MicroServer can throw
    /// </summary>
    [Serializable]
    public class TinyServerException : ApplicationException
    {
        /// <summary>
        /// Initializes a new instance of the TinyServerException class.
        /// </summary>
        /// <param name="msg">Message of the exception</param>
        public TinyServerException(string msg) : base(msg) 
        {
        }

        /// <summary>
        /// Initializes a new instance of the TinyServerException class.
        /// </summary>
        /// <param name="fmt">Template for the message of the exception</param>
        /// <param name="args">Arguments for the template.</param>
        public TinyServerException(string fmt, params object[] args) : base(string.Format(fmt, args)) 
        {
        }

        /// <summary>
        /// Initializes a new instance of the TinyServerException class.
        /// </summary>
        /// <param name="msg">Message of the exception</param>
        /// <param name="innerException">Inner exception.</param>
        public TinyServerException(string msg, Exception innerException) : base(msg, innerException) 
        {
        }
    }
}
